@@ -2,16 +2,28 @@
 
 """Pure Python tools for NECST."""
 
-try:
-    from importlib.metadata import version  # Python 3.8+
-except ImportError:
-    from importlib_metadata import version
+import logging
+import sys
+from importlib.metadata import version
+
 
 try:
     __version__ = version("neclib")
 except:
     __version__ = "0.0.0"  # Fallback.
 
+
+logger = logging.getLogger("neclib")
+
+if sys.platform != "linux":
+    logger.warning(
+        "Device drivers for Interface PCI boards are only supported on Linux."
+    )
+
+from .configuration import config, configure
+
+config = config
+
 # Aliases
 from .exceptions import *
 
@@ -23,5 +35,6 @@ from . import units
 from . import controllers
 from . import interfaces
 from . import parameters
+from . import recorders
 from . import simulators
 from . import utils
