@@ -1,6 +1,6 @@
 """Informative exception, regarding the NECST system status."""
 
-__all__ = ["NECSTAuthorityError"]
+__all__ = ["NECSTAuthorityError", "ConfigurationError"]
 
 
 class NECSTAuthorityError(Exception):
@@ -13,3 +13,9 @@ class NECSTAuthorityError(Exception):
     """
 
     pass
+
+
+class ConfigurationError(Exception):
+    """Error related to parameter configuration."""
+
+    pass
